@@ -41,7 +41,7 @@ addAttributes.coCovar <- function(x, name, ...)
 	{
 		attr(x, 'poszvar') <- TRUE
 	}
-	attr(x, 'range') <- rr$range[2] - rr$range[1]
+	attr(x, 'range') <- ifelse((rr$range[2] - rr$range[1]==0), 1, rr$range[2] - rr$range[1])
 	storage.mode(attr(x, 'range')) <- 'double'
 	attr(x, 'range2') <- range2
 	## attr(x, 'simTotal') <- rr$simTotal
@@ -190,7 +190,7 @@ addAttributes.varDyadCovar <- function(x, name, bipartite, ...)
 		nonMissingCounts <- colSums(!is.na(x), dims=2)
 	}
 	attr(x, "mean") <- ifelse(attr(x, "centered"), varmean, 0)
-	attr(x, "range") <- rr[2] - rr[1]
+	attr(x, "range") <- ifelse((rr[2] - rr[1]==0), 1, rr[2] - rr[1])
 	storage.mode(attr(x, "range")) <- "double"
 	attr(x, "name") <- name
 	attr(x, "nonMissingCount") <- nonMissingCounts
@@ -431,11 +431,11 @@ sienaDataCreate<- function(..., nodeSets=NULL, getDocumentation=FALSE)
 		}
 		if (!validNodeSet(nattr[1], nrow(thisdycCovar)))
 		{
-			stop("dyadic covariate incorrect nbr rows", names(dycCovars)[i])
+			stop("dyadic covariate incorrect nbr rows ", names(dycCovars)[i])
 		}
 		if (!validNodeSet(nattr[2], ncol(thisdycCovar)))
 		{
-			 stop("dyadic covariate incorrect nbr columns",
+			 stop("dyadic covariate incorrect nbr columns ",
 				  names(dycCovars)[i])
 		 }
 		dycCovars[[i]] <- addAttributes(dycCovars[[i]], names(dycCovars)[i],
@@ -977,7 +977,7 @@ sienaDataCreate<- function(..., nodeSets=NULL, getDocumentation=FALSE)
 	if (someOnly)
 	{
 message('For some variables, in some periods, there are only increases, or only decreases.')
-message('This will be respected in the simulations.')
+message('This will be respected in the simulations. ')
 message('If this is not desired, use allowOnly=FALSE when creating the dependent variables.')
 	}
 	## create the object
@@ -1053,7 +1053,7 @@ checkConstraints <- function(z)
 			symmetric2 <- symmetrics[net2]
 
 			if (type1 == type2 && type1 != "behavior" && nodes1 == nodes2
-				&& symmetric1 == symmetric2 && type1 != "continuous" 
+				&& symmetric1 == symmetric2 && type1 != "continuous"
 				&& type2 != "continuous")
 			{
 				higher[i] <- TRUE
@@ -1115,8 +1115,8 @@ checkConstraints <- function(z)
 						".\n"), sep="")
 		  })
 		message(report)
-		cat("This will be respected in the simulations.")
-		cat("If this is not desired, change attribute 'atLeastOne'\n")
+		cat("This will be respected in the simulations. ")
+		cat("If this is not desired, change attribute 'higher'\n")
 		cat("by function sienaDataConstraint.\n")
 	}
 	if (any(disjoint))
@@ -1129,7 +1129,7 @@ checkConstraints <- function(z)
 		  })
 		message(report)
 		cat("This will be respected in the simulations.\n")
-		cat("If this is not desired, change attribute 'disjoint'.\n")
+		cat("If this is not desired, change attribute 'disjoint'\n")
 		cat("by function sienaDataConstraint.\n")
 
 	}
@@ -1143,7 +1143,7 @@ checkConstraints <- function(z)
 					   " always exists.\n"), sep="")
 		  })
 		message(report)
-		message("This will be respected in the simulations.")
+		cat("This will be respected in the simulations.")
 		cat("If this is not desired, change attribute 'atLeastOne'\n")
 		cat("by function sienaDataConstraint.\n")
 	}
@@ -1151,17 +1151,26 @@ checkConstraints <- function(z)
 }
 
 ##@rangeAndSimilarity DataCreate
-rangeAndSimilarity<- function(vals, rvals=NULL)
+rangeAndSimilarity <- function(vals, rvals=NULL)
 {
-	vals <- as.matrix(vals)
+	zeroOrNA <- function(x){ifelse(is.na(x), TRUE, (x==0))}
 	if (is.null(rvals))
 	{
 		rvals <- range(vals, na.rm=TRUE)
 	}
-	rvals1 <- rvals[2] - rvals[1]
-	tmp <- apply(vals, 2, function(v)
+	if (zeroOrNA(var(as.vector(vals), na.rm=TRUE)))
+	{
+		simTotal <- 0
+		simCnt <- sum(!is.na(vals))^2
+		simMean <- 0
+	}
+	else
+	{
+		vals <- as.matrix(vals)
+		rvals1 <- rvals[2] - rvals[1]
+		tmp <- apply(vals, 2, function(v)
 			 {
-				 sapply(1: length(v), function(x, y, r)
+				sapply(1: length(v), function(x, y, r)
 					{
 						z <- y
 						z[x] <- NA
@@ -1171,16 +1180,18 @@ rangeAndSimilarity<- function(vals, rvals=NULL)
 					},
 						y=v, r=rvals1)
 			 }
-				 )
-	tmp <- unlist(tmp)
-	raw <- tmp[seq(1, length(tmp), by=2)]
-	cnts <- tmp[seq(2, length(tmp), by=2)]
-	simTotal <- sum(raw)
-	simCnt <- sum(cnts)
-	simMean <- simTotal/simCnt
+					)
+		tmp <- unlist(tmp)
+		raw <- tmp[seq(1, length(tmp), by=2)]
+		cnts <- tmp[seq(2, length(tmp), by=2)]
+		simTotal <- sum(raw)
+		simCnt <- sum(cnts)
+		simMean <- ifelse(simCnt==0, 0, simTotal/simCnt)
+	}
 	list(simTotal=simTotal, simMean=simMean, range=rvals, simCnt=simCnt)
 }
 ##@groupRangeAndSimilarityAndMean DataCreate
+## calculates attributes at group level and re-centers actor covariates
 groupRangeAndSimilarityAndMean <- function(group)
 {
 	atts <- attributes(group)
@@ -1232,7 +1243,7 @@ groupRangeAndSimilarityAndMean <- function(group)
 			simCnt <- simCnt + tmp$simCnt
 			values <- c(values, unique(depvar))
 		}
-		simMean <- simTotal/simCnt
+		simMean <- ifelse(simCnt==0, 0, simTotal/simCnt)
 		bSim[net] <- simMean
 		bMoreThan2[net] <- length(unique(values)) > 2
 		if (anyMissing)
@@ -1257,7 +1268,6 @@ groupRangeAndSimilarityAndMean <- function(group)
 		thisrange <- matrix(NA, ncol=length(group),nrow=2)
 		for (i in 1:length(group))
 		{
-
 			j <- match(atts$cCovars[covar], names(group[[i]]$cCovars))
 			if (is.na(j))
 			{
@@ -1277,7 +1287,6 @@ groupRangeAndSimilarityAndMean <- function(group)
 		##then calculate similarity
 		for (i in 1:length(group))
 		{
-
 			j <- match(atts$cCovars[covar], names(group[[i]]$cCovars))
 			tmp <- rangeAndSimilarity(group[[i]]$cCovars[[covar]],
 									  rr)
@@ -1313,15 +1322,15 @@ groupRangeAndSimilarityAndMean <- function(group)
 			{
 				stop(paste("Inconsistent centering for covariate", names(group[[i]]$vCovars)[j]))
 			}
-			if (attr(group[[i]]$vCovars[[j]],"centered"))
-			{
 			vartotal <- vartotal + attr(group[[i]]$vCovars[[j]], "vartotal")
 			nonMissingCount <- nonMissingCount +
-				attr(group[[i]]$vCovars[[j]], "nonMissingCount")
-			group[[i]]$vCovars[[j]] <- group[[i]]$vCovars[[j]] +
-				attr(group[[i]]$vCovars[[j]], "vartotal") /
 					attr(group[[i]]$vCovars[[j]], "nonMissingCount")
-		}
+			if (attr(group[[i]]$vCovars[[j]],"centered"))
+			{
+				group[[i]]$vCovars[[j]] <- group[[i]]$vCovars[[j]] +
+					attr(group[[i]]$vCovars[[j]], "vartotal") /
+						attr(group[[i]]$vCovars[[j]], "nonMissingCount")
+			}
 		}
 		varmean <- vartotal / nonMissingCount
 		j <- match(atts$vCovars[covar], names(group[[1]]$vCovars))
@@ -1346,7 +1355,6 @@ groupRangeAndSimilarityAndMean <- function(group)
 		values <- NULL
 		for (i in 1:length(group))
 		{
-
 			j <- match(atts$vCovars[covar], names(group[[i]]$vCovars))
 			if (is.na(j))
 			{
@@ -1369,7 +1377,6 @@ groupRangeAndSimilarityAndMean <- function(group)
 		##then calculate similarity. Note ignore final observation
 		for (i in 1:length(group))
 		{
-
 			j <- match(atts$vCovars[covar], names(group[[i]]$vCovars))
 			tmpmat <- group[[i]]$vCovars[[covar]]
 			tmp <- rangeAndSimilarity(tmpmat, rr)
@@ -1401,6 +1408,8 @@ groupRangeAndSimilarityAndMean <- function(group)
 	}
 	dyvCovarMean <- namedVector(NA, atts$dyvCovars)
 	dyvCovarRange <- namedVector(NA, atts$dyvCovars)
+	dyvCovarRange2 <- matrix(NA, 2, length(atts$dyvCovars))
+	colnames(dyvCovarRange2) <- atts$dyvCovars
 	for (covar in seq(along=atts$dyvCovars))
 	{
 		vartotal <- 0
@@ -1445,6 +1454,7 @@ groupRangeAndSimilarityAndMean <- function(group)
 		}
 		dyvCovarMean[covar] <- ifelse(centered, vartotal / nonMissingCount, 0)
 		rr <- range(thisrange, na.rm=TRUE)
+		dyvCovarRange2[,covar] <- rr
 		dyvCovarRange[covar] <- rr[2] - rr[1]
    }
 	attr(group, "bRange") <- bRange
@@ -1468,6 +1478,7 @@ groupRangeAndSimilarityAndMean <- function(group)
 	attr(group, "dycCovarRange") <- dycCovarRange
 	attr(group, "dycCovarRange2") <- dycCovarRange2
 	attr(group, "dyvCovarRange") <- dyvCovarRange
+	attr(group, "dyvCovarRange2") <- dyvCovarRange2
 	attr(group, "dyvCovarMean") <- dyvCovarMean
 	group
 }
@@ -1489,7 +1500,7 @@ namedVector <- function(vectorValue, vectorNames, listType=FALSE)
 
 ##@createSettings DataCreate
 # create a settings structure for sienaData object x
-createSettings <- function(x, varName=1)
+createSettings <- function(x, varName=1, model=TRUE)
 ##
 {
 	if (!inherits(x, 'siena'))
@@ -1504,9 +1515,11 @@ createSettings <- function(x, varName=1)
 	{
 		stop('varName should refer to a dependent network variable in x')
 	}
+	universalOnly <- ifelse(model, "up", "none")
 	attr(x$depvars[[varName]], 'settingsinfo') <- list(
-		list(id="universal", type="universal", only="up", covariate=""),
+		list(id="universal", type="universal", only=universalOnly, covariate=""),
 		list(id="primary", type="primary", only="both", covariate=""))
+# universal MUST be mentioned first here, and primary second.
 	x
 }
 
@@ -1542,7 +1555,7 @@ hasSettings <- function(x, varName=NULL)
 			}
 		}
 	}
-	hasSettingsi <- rep('',FALSE)
+	hasSettingsi <- rep(FALSE, length(varNames))
 	for (i in seq(along = varNames))
 	{
 		hasSettingsi[i] <- (!is.null(attr(x$depvars[[varNames[i]]], 'settingsinfo')))
@@ -1579,7 +1592,7 @@ describeTheSetting <- function(depvar)
 		dtsonly  <- sapply(dtsonly, function(x){ifelse(is.na(x),'both',x)})
 		dts <- cbind(dtsn, dtsid, dtstype, dtscovar, dtsonly)
 		colnames(dts) <- c('dependent variable', 'setting', 'type', 'covariate', 'direction')
-		rownames(dts) <- 1:dim(dts)[1]
+		rownames(dts) <- 1:seq_len(dtsn)
 	}
 	dts
 }
@@ -1766,7 +1779,7 @@ sienaGroupCreate <- function(objlist, singleOK=FALSE, getDocumentation=FALSE)
 					numberNonMissingNetwork[observations + (1 : (newobs - 1))] +
 						attribs[["nonMissingEither"]]
 			}
-	   }
+		}
 		thisHigher <- attr(objlist[[i]], "higher")
 		thisDisjoint <- attr(objlist[[i]], "disjoint")
 		thisAtLeastOne <- attr(objlist[[i]], "atLeastOne")
@@ -1886,7 +1899,7 @@ sienaGroupCreate <- function(objlist, singleOK=FALSE, getDocumentation=FALSE)
 					varCovar(matrix(const[[j]],
 									ncol = objlist[[i]]$observations - 1,
 									nrow=length(const[[j]])),
-							 nodeSet=attr(const[[j]], "nodeSet"))
+							 nodeSet=attr(const[[j]], "nodeSet"), warn=FALSE)
 				newcovar <- copyAttributes(newcovar, const[[j]])
 				nVCovar <- nVCovar + 1
 				vars[[nVCovar]] <- newcovar
@@ -1909,7 +1922,7 @@ sienaGroupCreate <- function(objlist, singleOK=FALSE, getDocumentation=FALSE)
 				newcovar <-
 					varDyadCovar(array(const[[j]], dim=c(dim(const[[j]]),
 												   dim3)),
-								 nodeSets=attr(const[[j]], "nodeSet"))
+								 nodeSets=attr(const[[j]], "nodeSet"), warn=FALSE)
 				attr(newcovar, "vartotal") <- attr(const[[j]], "vartotal")
 				attr(newcovar, "nonMissingCount") <-
 					 attr(const[[j]], "nonMissingCount")
@@ -2033,43 +2046,46 @@ sienaGroupCreate <- function(objlist, singleOK=FALSE, getDocumentation=FALSE)
 	tmp <- getGroupNetRanges(group)
 	colnames(tmp) <- netnames
 	attr(group, "netRanges") <- tmp
-
-	##copy the global attributes down to individual level where appropriate
-	##group <- copyGroupAttributes(group, "depvars", "balmean", "balmean")
-	##group <- copyGroupAttributes(group, "depvars", "structmean",
-	## "structmean")
-	group <- copyGroupAttributes(group, "depvars", "symmetric", "symmetric")
-	##group <- copyGroupAttributes(group, "depvars", "averageInDegree",
-	##							   "averageInDegree")
-	##group <- copyGroupAttributes(group, "depvars", "averageOutDegree",
-	##							   "averageOutDegree")
-	##group <- copyGroupAttributes(group, "depvars", "bSim", "simMean")
-	group <- copyGroupAttributes(group, "depvars", "bposzvar", "poszvar")
-	group <- copyGroupAttributes(group, "depvars", "bRange", "range")
 	group <- copyGroupAttributes(group, "depvars", "behRange", "behRange")
-	group <- copyGroupAttributes(group, "depvars", "bMoreThan2",
+	if (length(group) >= 2)
+	{
+		##copy the global attributes down to individual level where appropriate
+		##group <- copyGroupAttributes(group, "depvars", "balmean", "balmean")
+		##group <- copyGroupAttributes(group, "depvars", "structmean",
+		## "structmean")
+		group <- copyGroupAttributes(group, "depvars", "symmetric", "symmetric")
+		##group <- copyGroupAttributes(group, "depvars", "averageInDegree",
+		##							   "averageInDegree")
+		##group <- copyGroupAttributes(group, "depvars", "averageOutDegree",
+		##							   "averageOutDegree")
+		##group <- copyGroupAttributes(group, "depvars", "bSim", "simMean")
+		group <- copyGroupAttributes(group, "depvars", "bposzvar", "poszvar")
+		group <- copyGroupAttributes(group, "depvars", "bRange", "range")
+		group <- copyGroupAttributes(group, "depvars", "bMoreThan2",
 								 "moreThan2")
-	group <- copyGroupAttributes(group, "depvars", "anyMissing", "missing")
-	group <- copyGroupAttributes(group, "depvars", "structural",
+		group <- copyGroupAttributes(group, "depvars", "anyMissing", "missing")
+		group <- copyGroupAttributes(group, "depvars", "structural",
 								 "structural")
-
-	##group <- copyGroupAttributes(group, "vCovars", "vCovarSim", "simMean")
-	group <- copyGroupAttributes(group, "vCovars", "vCovarRange", "range",
+		##group <- copyGroupAttributes(group, "vCovars", "vCovarSim", "simMean")
+		group <- copyGroupAttributes(group, "vCovars", "vCovarRange", "range",
 								 TRUE)
-	##group <- copyGroupAttributes(group, "vCovars", "vCovarMean", "mean",
-	## TRUE)
-	group <- copyGroupAttributes(group, "vCovars", "vCovarPoszvar",
+		##group <- copyGroupAttributes(group, "vCovars", "vCovarMean", "mean",
+		## TRUE)
+		group <- copyGroupAttributes(group, "vCovars", "vCovarPoszvar",
 								 "poszvar")
-	group <- copyGroupAttributes(group, "vCovars", "vCovarMoreThan2",
+		group <- copyGroupAttributes(group, "vCovars", "vCovarMoreThan2",
 								 "moreThan2")
-	##group <- copyGroupAttributes(group, "dycCovars", "dycCovarMean",
-	##	"mean")
-	group <- copyGroupAttributes(group, "dycCovars", "dycCovarRange2",
+		##group <- copyGroupAttributes(group, "dycCovars", "dycCovarMean",
+		##	"mean")
+		group <- copyGroupAttributes(group, "dycCovars", "dycCovarRange2",
 								 "range2", TRUE)
-	##group <- copyGroupAttributes(group, "dyvCovars", "dyvCovarMean",
-	## "mean")
-	group <- copyGroupAttributes(group, "dyvCovars", "dyvCovarRange",
+		##group <- copyGroupAttributes(group, "dyvCovars", "dyvCovarMean",
+		## "mean")
+		group <- copyGroupAttributes(group, "dyvCovars", "dyvCovarRange",
 								 "range", TRUE)
+		group <- copyGroupAttributes(group, "dyvCovars", "dyvCovarRange2",
+								 "range2", TRUE)
+	}
 	group
 }
 ##@copyGroupAttributes DataCreate
@@ -2492,5 +2508,5 @@ calcCovarDist2 <- function(covar, depvar, rval=NULL)
 		simTotal[i] <- tmp$simTotal
 		simCnt[i] <- tmp$simCnt
 	}
-	sum(simTotal)/sum(simCnt)
+	ifelse(sum(simCnt)==0, 0, sum(simTotal)/sum(simCnt))
 }
