@@ -21,14 +21,13 @@ namespace siena
 class SameCovariateInTiesFunction: public CovariateNetworkAlterFunction
 {
 public:
-	SameCovariateInTiesFunction(string networkName,
-		string covariateName, bool sameValue, bool sameVariable,
-								bool excludeMissing);
+	SameCovariateInTiesFunction(std::string networkName,
+			std::string covariateName, bool sameValue, bool sameVariable,
+			bool excludeMissing);
 
 	virtual void initialize(const Data * pData,
-		State * pState,
-		int period,
-		Cache * pCache);
+		State * pState, int period, Cache * pCache);
+
 	virtual void preprocessEgo(int ego);
 	virtual double value(int alter);
 
