@@ -20,15 +20,15 @@ namespace siena
 class SameCovariateTwoPathFunction: public CovariateNetworkAlterFunction
 {
 public:
-	SameCovariateTwoPathFunction(string networkName,
-		string covariateName, bool excludeMissing);
+	SameCovariateTwoPathFunction(std::string networkName,
+		std::string covariateName, bool excludeMissing);
 		
 	virtual void initialize(const Data * pData,
 		State * pState,
 		int period,
 		Cache * pCache);
 
-		virtual double value(int alter);
+	virtual double value(int alter);
 
 private:
 	bool lexcludeMissing;
